summaryrefslogtreecommitdiffstats
path: root/juk/filerenamer.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'juk/filerenamer.cpp')
-rw-r--r--juk/filerenamer.cpp28
1 files changed, 14 insertions, 14 deletions
diff --git a/juk/filerenamer.cpp b/juk/filerenamer.cpp
index e4ddee28..6f479313 100644
--- a/juk/filerenamer.cpp
+++ b/juk/filerenamer.cpp
@@ -44,7 +44,7 @@
#include <tqcheckbox.h>
#include <tqdir.h>
#include <tqlabel.h>
-#include <layout.h>
+#include <tqlayout.h>
#include <tqsignalmapper.h>
#include <tqheader.h>
@@ -232,7 +232,7 @@ FileRenamerWidget::FileRenamerWidget(TQWidget *parent) :
m_exampleText->setPaletteBackgroundColor(temp->paletteBackgroundColor());
delete temp;
- layout()->setMargin(0); // We'll be wrapped by KDialogBase
+ tqlayout()->setMargin(0); // We'll be wrapped by KDialogBase
// This must be created before createTagRows() is called.
@@ -352,10 +352,10 @@ unsigned FileRenamerWidget::addRowCategory(TagType category)
downMapper->connect(row.downButton, TQT_SIGNAL(clicked()), TQT_SLOT(map()));
downMapper->setMapping(TQT_TQOBJECT(row.downButton), id);
- TQString labelText = TQString("<b>%1</b>").arg(TagRenamerOptions::tagTypeText(category));
+ TQString labelText = TQString("<b>%1</b>").tqarg(TagRenamerOptions::tagTypeText(category));
TQLabel *label = new TQLabel(labelText, frame);
frame->setStretchFactor(label, 1);
- label->setAlignment(AlignCenter);
+ label->tqsetAlignment(AlignCenter);
TQVBox *options = new TQVBox(frame);
row.enableButton = new KPushButton(i18n("Remove"), options);
@@ -410,7 +410,7 @@ bool FileRenamerWidget::removeRow(unsigned id)
if(m_rows[id].position > 0)
checkboxPosition = m_rows[id].position - 1;
// The checkbox is contained within a layout widget, so the layout
// widget is the one the needs to die.
delete m_folderSwitches[checkboxPosition]->parent();
m_folderSwitches.erase(&m_folderSwitches[checkboxPosition]);
@@ -675,17 +675,17 @@ void FileRenamerWidget::moveItem(unsigned id, MovementDirection direction)
// Move the item two spaces above/below its previous position. It has to
// be 2 spaces because of the checkbox.
- TQBoxLayout *layout = dynamic_cast<TQBoxLayout *>(m_mainFrame->layout());
+ TQBoxLayout *tqlayout = dynamic_cast<TQBoxLayout *>(m_mainFrame->tqlayout());
- layout->remove(l);
- layout->insertWidget(2 * newPos, l);
+ tqlayout->remove(l);
+ tqlayout->insertWidget(2 * newPos, l);
// Move the top item two spaces in the opposite direction, for a similar
// reason.
- layout->remove(w);
- layout->insertWidget(2 * pos, w);
- layout->invalidate();
+ tqlayout->remove(w);
+ tqlayout->insertWidget(2 * pos, w);
+ tqlayout->tqinvalidate();
TQTimer::singleShot(0, this, TQT_SLOT(exampleTextChanged()));
}
@@ -778,7 +778,7 @@ void FileRenamerWidget::insertCategory()
// Set its down button to be disabled.
m_rows[id].downButton->setEnabled(false);
- m_mainFrame->layout()->invalidate();
+ m_mainFrame->tqlayout()->tqinvalidate();
m_mainView->update();
// Now update according to the code in loadConfig().
@@ -875,7 +875,7 @@ void FileRenamer::rename(const PlaylistItemList &items)
setFolderIcon(it.data(), itemMap[it.key()]);
}
else
- errorFiles << i18n("%1 to %2").arg(it.key()).arg(it.data());
+ errorFiles << i18n("%1 to %2").tqarg(it.key()).tqarg(it.data());
processEvents();
}
@@ -952,7 +952,7 @@ void FileRenamer::setFolderIcon(const KURL &dst, const PlaylistItem *item)
config.setGroup("Desktop Entry");
if(!config.hasKey("Icon")) {
- config.writeEntry("Icon", TQString("%1/.juk-thumbnail.png").arg(path));
+ config.writeEntry("Icon", TQString("%1/.juk-thumbnail.png").tqarg(path));
config.sync();
}
@@ -410,7 +410,7 @@ bool FileRenamerWidget::removeRow(unsigned id)
if(m_rows[id].position > 0)
checkboxPosition = m_rows[id].position - 1;
- // The checkbox is contained within a layout widget, so the layout
+ // The checkbox is contained within a tqlayout widget, so the tqlayout
// widget is the one the needs to die.
delete m_folderSwitches[checkboxPosition]->parent();